@@ -23,15 +23,14 @@
  *imports Plain text messages into KMail
  *@author laurence
  */
-namespace MailImporter
-{
+namespace MailImporter {
 class MAILIMPORTER_EXPORT FilterPlain : public Filter
 {
 public:
     FilterPlain();
-    ~FilterPlain();
+    ~FilterPlain() override;
 
-    void import() Q_DECL_OVERRIDE;
+    void import() override;
     void importMails(const QString &mailDir);
 };
 }
